@@ -693,6 +693,32 @@ class Project:
         self.impl.ImportCountCSV(experiment, "temp.csv")
         os.remove("temp.csv")
 
+    @_closed_project_decorator
+    def get_thresholds(
+        self, experiment: str = "default", preset: int = 1
+    ) -> np.array:
+        """
+        Returns a numpy array spanning all of the channels on the first axis,
+        which will have a size equal to the number of channels, and spanning the
+        lower and upper thresholds on the second axis, which will always have
+        a size of 2.
+
+        :param experiment: the name of the experiment from which to retrieve
+                           threshold settings
+        :param preset: the shader preset number to retrieve
+        :return: a numpy array containing the thresholds for each channel
+        """
+        
+        channel_count = self.get_channel_count()
+        threshold_result = np.zeros((channel_count, 2), dtype=np.int32)
+        threshold_impl = self.impl.GetThresholds(experiment, preset - 1)
+
+        for c in range(channel_count):
+            threshold_result[c][0] = threshold_impl[c].x
+            threshold_result[c][1] = threshold_impl[c].y
+
+        return threshold_result
+
     @_closed_project_decorator
     def get_distance_measurements(
         self, experiment: str = "default"
